package com.ruoyi.system.service.impl;

import com.ruoyi.system.api.domain.SysUser;
import com.alibaba.fastjson2.JSONWriter;
import com.ruoyi.system.utils.RequestUtil;
import java.util.ArrayList;
import com.alibaba.fastjson2.JSONObject;
import java.util.Iterator;
import java.util.stream.Collectors;
import java.util.Map;
import java.util.function.Function;
import com.ruoyi.system.domain.dto.UpdateBaseParams;
import org.apache.commons.lang3.tuple.Triple;
import com.ruoyi.system.utils.SSLExpirationChecker;
import com.ruoyi.system.domain.dto.DeploySSLParams;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.transaction.annotation.Transactional;
import com.ruoyi.common.core.constant.Constants;
import com.ruoyi.common.core.domain.StrFile;
import com.ruoyi.common.core.utils.file.FileUtils;
import com.ruoyi.common.core.domain.R;
import org.springframework.web.multipart.MultipartFile;
import java.nio.file.Path;
import com.ruoyi.system.api.domain.SysFile;
import com.ruoyi.system.utils.FileConversionUtil;
import com.ruoyi.system.utils.ZipTool;
import org.apache.commons.lang3.tuple.Pair;
import com.ruoyi.system.domain.SnTemplate;
import com.ruoyi.system.domain.SnServer;
import com.ruoyi.system.domain.SnServerTask;
import java.util.Objects;
import com.ruoyi.common.core.utils.StringUtils;
import java.util.List;
import com.ruoyi.system.domain.SnServerTemplate;
import com.ruoyi.system.api.model.LoginUser;
import com.ruoyi.common.core.utils.ServletUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.beans.factory.annotation.Value;
import com.ruoyi.system.mapper.SnServerTaskMapper;
import com.ruoyi.system.kernel.SslCountLimit;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.system.kernel.SslNginxConfigDealKernel;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.mq.ServerTaskSender;
import com.ruoyi.system.kernel.CreateShellTaskKernel;
import com.ruoyi.system.api.RemoteFileService;
import com.ruoyi.system.mapper.SnTemplateMapper;
import com.ruoyi.system.mapper.SnServerMapper;
import com.ruoyi.system.kernel.DomainValidKernel;
import com.ruoyi.common.security.service.TokenService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.mapper.SnServerTemplateMapper;
import org.springframework.stereotype.Service;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import com.ruoyi.system.service.ISnServerTemplateService;

@RefreshScope
@Service
public class SnServerTemplateServiceImpl implements ISnServerTemplateService
{
    @Autowired
    private SnServerTemplateMapper snServerTemplateMapper;
    @Autowired
    private TokenService tokenService;
    @Autowired
    private DomainValidKernel domainValidKernel;
    @Autowired
    private SnServerMapper snServerMapper;
    @Autowired
    private SnTemplateMapper snTemplateMapper;
    @Autowired
    private RemoteFileService remoteFileService;
    @Autowired
    private CreateShellTaskKernel createShellTaskKernel;
    @Autowired
    private ServerTaskSender serverTaskSender;
    @Autowired
    private ISysDictDataService dictDataService;
    @Autowired
    private SslNginxConfigDealKernel sslNginxConfigDealKernel;
    @Autowired
    private ISysUserService sysUserService;
    @Autowired
    private SslCountLimit sslCountLimit;
    @Autowired
    private SnServerTaskMapper snServerTaskMapper;
    @Value("${baseNginxUrl}")
    public String baseNginxUrl;
    @Value("${wpPluginName}")
    public String wpPluginName;
    
    public AjaxResult getOwnLast(final Long serverId) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        return AjaxResult.success((Object)this.snServerTemplateMapper.getOwnLast(serverId, loginUser.getUserid()));
    }
    
    public SnServerTemplate selectSnServerTemplateById(final Long id) {
        final SnServerTemplate obj = this.snServerTemplateMapper.selectSnServerTemplateById(id);
        if (obj == null || obj.getIsDelete().equals(1)) {
            return null;
        }
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        if (loginUser.getRoles().contains("admin") || loginUser.getRoles().contains("super")) {
            return obj;
        }
        if (loginUser.getRoles().contains("dealer")) {
            return obj.getDealerId().equals(loginUser.getUserid()) ? obj : null;
        }
        if (loginUser.getRoles().contains("agent")) {
            return obj.getAgentId().equals(loginUser.getUserid()) ? obj : null;
        }
        return obj.getCreateId().equals(loginUser.getUserid()) ? obj : null;
    }
    
    public List<SnServerTemplate> selectSnServerTemplateList(final SnServerTemplate obj) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        if (loginUser.getRoles().contains("dealer")) {
            obj.setDealerId(loginUser.getUserid());
        }
        if (loginUser.getRoles().contains("agent")) {
            obj.setAgentId(loginUser.getUserid());
        }
        if (loginUser.getRoles().contains("common")) {
            obj.setCreateId(loginUser.getUserid());
        }
        obj.setIsDelete(Integer.valueOf(0));
        if (StringUtils.isNotEmpty(obj.getCategory())) {
            obj.getParams().put("categoryList", obj.getCategory().split(","));
        }
        return this.snServerTemplateMapper.selectSnServerTemplateList(obj);
    }
    
    public AjaxResult insertSnServerTemplate(final SnServerTemplate param) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        final SnServer server = this.snServerMapper.selectSnServerByServerId(param.getServerId());
        if (server == null) {
            return AjaxResult.error("未查询到服务器信息");
        }
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(server.getCreateId(), loginUser.getUserid()) && !Objects.equals(server.getAgentId(), loginUser.getUserid())) {
            return AjaxResult.error("您无权操作此服务器");
        }
        if (!Objects.equals(server.getStatus(), 2)) {
            return AjaxResult.error("此服务器处于【" + this.dictDataService.selectDictLabel("server_status", server.getStatus().toString()) + "】状态，不能安装模板");
        }
        final SnTemplate template = this.snTemplateMapper.selectSnTemplateByTemplateId(param.getTemplateId());
        if (template == null) {
            return AjaxResult.error("未获取到模板，请联系管理员");
        }
        if (!Objects.equals(template.getStatus(), 1)) {
            return AjaxResult.error("当前模板已下架，请选择其他模板");
        }
        if (template.getCategory() == 6) {
            return this.generateWp(param, template, server);
        }
        final Pair<SnServerTask, String> pair = this.insertTemplate(param, template, server);
        if (pair.getLeft() != null) {
            this.serverTaskSender.sendOrderMessage(pair.getLeft().getTaskId());
        }
        if (StringUtils.isNotEmpty((String)pair.getRight())) {
            return AjaxResult.error((String)pair.getRight());
        }
        return AjaxResult.success("部署中，请稍后查看服务器任务状态");
    }
    
    private AjaxResult generateWp(final SnServerTemplate param, final SnTemplate template, final SnServer server) {
        final String domain = param.getDomain();
        final SnServerTemplate query = new SnServerTemplate();
        query.setTemplateId(param.getTemplateId());
        query.setServerId(param.getServerId());
        query.getParams().put("domain", domain);
        query.setIsDelete(Integer.valueOf(0));
        if (!this.snServerTemplateMapper.selectSnServerTemplateList(query).isEmpty()) {
            return AjaxResult.error("当前服务器已生成相同域名的插件，请到插件列表查看");
        }
        try {
            final Path newZipPath = ZipTool.generateWpPlugin(template.getPackUrl(), domain, server.getDomain(), this.wpPluginName);
            final MultipartFile file = FileConversionUtil.pathToMultipartFile(newZipPath);
            final R<SysFile> fileResult = (R<SysFile>)this.remoteFileService.upload(file);
            ZipTool.deleteDirectory(newZipPath);
            if (StringUtils.isNull((Object)fileResult) || StringUtils.isNull(fileResult.getData())) {
                return AjaxResult.error("生成插件异常，请稍后再试");
            }
            final String url = ((SysFile)fileResult.getData()).getUrl();
            final SnServerTemplate obj = new SnServerTemplate(server, template);
            obj.setDomain(domain);
            obj.setStatus(Integer.valueOf(2));
            obj.setNginxCnf(url);
            this.snServerTemplateMapper.insertSnServerTemplate(obj);
            this.snTemplateMapper.updateSnTemplateUseNum(template.getTemplateId());
            return AjaxResult.success((Object)obj);
        }
        catch (final Exception ignore) {
            return AjaxResult.error("生成插件异常，请稍后再试");
        }
    }
    
    @Transactional
    public Pair<SnServerTask, String> insertTemplate(final SnServerTemplate param, final SnTemplate template, final SnServer server) {
        final String domain = param.getDomain();
        final AjaxResult result = this.domainValidKernel.checkDomain(domain, server.getIp(), (Long)null);
        if (!result.isSuccess()) {
            return Pair.of((SnServerTask)null, result.get((Object)"msg"));
        }
        String nginxConfig = FileUtils.readFile(this.baseNginxUrl);
        nginxConfig = nginxConfig.replace("#{server_name}", domain);
        nginxConfig = nginxConfig.replace("#{client_root}", "");
        nginxConfig = nginxConfig.replace("#{open_80}", "");
        final StrFile strFile = new StrFile();
        strFile.setContent(nginxConfig);
        strFile.setFileName(domain + ".conf");
        strFile.setContentType("text/plain");
        final R<SysFile> r1 = (R<SysFile>)this.remoteFileService.uploadStrToMinio(strFile);
        if (r1.getCode() != Constants.SUCCESS) {
            return Pair.of((SnServerTask)null, r1.getMsg());
        }
        final String nginxUrl = ((SysFile)r1.getData()).getUrl();
        final SnServerTemplate obj = new SnServerTemplate(server, template);
        obj.setDomain(domain);
        obj.setNginxCnf(nginxUrl);
        obj.setProcess(param.getProcess());
        this.snServerTemplateMapper.insertSnServerTemplate(obj);
        final SnServerTask task = this.createShellTaskKernel.installClient(obj, template);
        if (task.getProcess() != null) {
            final SnServer upObj = new SnServer();
            upObj.setServerId(server.getServerId());
            upObj.setTaskId(task.getTaskId());
            this.snServerMapper.updateSnServer(upObj);
        }
        this.snTemplateMapper.updateSnTemplateUseNum(template.getTemplateId());
        return Pair.of(task, (String)null);
    }
    
    public int updateSnServerTemplate(final SnServerTemplate snServerTemplate) {
        if (this.selectSnServerTemplateById(snServerTemplate.getId()) == null) {
            return 0;
        }
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        snServerTemplate.setUpdateId(loginUser.getUserid());
        snServerTemplate.setUpdateName(loginUser.getUsername());
        snServerTemplate.setUpdateTime(DateUtils.getNowDate());
        return this.snServerTemplateMapper.updateSnServerTemplate(snServerTemplate);
    }
    
    public int deleteSnServerTemplateByIds(final Long[] ids) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        final SnServerTemplate query = new SnServerTemplate();
        query.getParams().put("serverTemplateIds", ids);
        final List<SnServerTemplate> templates = this.snServerTemplateMapper.selectSnServerTemplateList(query);
        if (templates.isEmpty()) {
            return 0;
        }
        final SnServer server = this.snServerMapper.selectSnServerByServerId(templates.get(0).getServerId());
        templates.forEach(template -> {
            final SnServerTask task = this.createShellTaskKernel.deleteClient(server, template);
            if (task != null) {
                if (loginUser.getRoles().contains("admin") || loginUser.getRoles().contains("super") || Objects.equals(template.getCreateId(), loginUser.getUserid()) || Objects.equals(template.getAgentId(), loginUser.getUserid())) {
                    this.serverTaskSender.sendOrderMessage(task.getTaskId());
                }
            }
            return;
        });
        Long createId = null;
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super")) {
            createId = loginUser.getUserid();
            return this.snServerTemplateMapper.deleteSnServerTemplateByIdsV2(ids, createId);
        }
        return this.snServerTemplateMapper.deleteSnServerTemplateByIds(ids);
    }
    
    public AjaxResult changeDomain(final SnServerTemplate param) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        final SnServerTemplate template = this.selectSnServerTemplateById(param.getId());
        if (template == null) {
            return AjaxResult.error("未查询到服务器客户端信息");
        }
        if (!Objects.equals(template.getStatus(), 2)) {
            return AjaxResult.error("此客户端处于【" + this.dictDataService.selectDictLabel("server_templ_status", template.getStatus().toString()) + "】状态，不能更换域名");
        }
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(template.getCreateId(), loginUser.getUserid()) && !Objects.equals(template.getAgentId(), loginUser.getUserid())) {
            return AjaxResult.error("您无权操作此服务器客户端");
        }
        final String oldDomain = template.getDomain();
        final String domain = param.getDomain();
        if (Objects.equals(oldDomain, domain)) {
            return AjaxResult.warn("域名已应用到当前服务器，请勿重复操作");
        }
        final AjaxResult result = this.domainValidKernel.checkDomain(domain, template.getServerIp(), (Long)null);
        if (!result.isSuccess()) {
            return result;
        }
        final AjaxResult res = this.updateClientConfig(template, domain, null);
        if (!res.isSuccess()) {
            return res;
        }
        String nginxConfig = FileUtils.readFile(this.baseNginxUrl);
        nginxConfig = nginxConfig.replace("#{server_name}", domain);
        nginxConfig = nginxConfig.replace("#{client_root}", "");
        nginxConfig = nginxConfig.replace("#{open_80}", "");
        final StrFile strFile = new StrFile();
        strFile.setContent(nginxConfig);
        strFile.setFileName(domain + ".conf");
        strFile.setContentType("text/plain");
        final R<SysFile> r1 = (R<SysFile>)this.remoteFileService.uploadStrToMinio(strFile);
        if (r1.getCode() != Constants.SUCCESS) {
            return AjaxResult.error(r1.getMsg());
        }
        final String nginxUrl = ((SysFile)r1.getData()).getUrl();
        final SnServerTemplate upObj = new SnServerTemplate();
        upObj.setId(template.getId());
        upObj.setDomain(domain);
        upObj.setNginxCnf(nginxUrl);
        upObj.setSslType(Integer.valueOf(0));
        this.updateSnServerTemplate(upObj);
        final SnServerTask task = this.createShellTaskKernel.changeClientDomain(this.snServerTemplateMapper.selectSnServerTemplateById(template.getId()), oldDomain);
        if (task != null) {
            this.serverTaskSender.sendOrderMessage(task.getTaskId());
        }
        return AjaxResult.success("更新中，请稍后查看服务器任务状态");
    }
    
    public AjaxResult deployDomainSSL(DeploySSLParams params) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        final SnServerTemplate template = this.selectSnServerTemplateById(params.getId());
        if (template == null) {
            return AjaxResult.error("未查询到服务器信息");
        }
        if (!Objects.equals(template.getStatus(), 2)) {
            return AjaxResult.error("此客户端处于【" + this.dictDataService.selectDictLabel("server_templ_status", template.getStatus().toString()) + "】状态，不能部署ssl证书");
        }
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(template.getCreateId(), loginUser.getUserid()) && !Objects.equals(template.getAgentId(), loginUser.getUserid())) {
            return AjaxResult.error("您无权操作此服务器客户端");
        }
        final String domain = template.getDomain();
        if (params.getType() == 1) {
            final AjaxResult res = this.sslCountLimit.validCount(domain, template.getServerIp());
            if (!res.isSuccess()) {
                return res;
            }
        }
        if (this.snServerTaskMapper.haveDealTask(template.getServerId(), "ssl证书", "0,1") > 0) {
            return AjaxResult.error("当前服务还有未执行完的ssl证书任务，请稍后再试");
        }
        final SnServerTemplate upObj = new SnServerTemplate();
        upObj.setId(template.getId());
        if (params.getType() == 2) {
            upObj.setSslTime(SSLExpirationChecker.getCertificateExDate(params.getSslPem()));
        }
        String nginxConfig = FileUtils.readFile(this.baseNginxUrl);
        final SnServer server = this.snServerMapper.selectSnServerByServerId(template.getServerId());
        final Triple<AjaxResult, DeploySSLParams, String> triple = this.sslNginxConfigDealKernel.deal(params, server, domain, nginxConfig);
        if (!triple.getLeft().isSuccess()) {
            return triple.getLeft();
        }
        nginxConfig = triple.getRight();
        params = triple.getMiddle();
        nginxConfig = nginxConfig.replace("#{client_root}", "");
        upObj.setSslPem(params.getSslPem());
        upObj.setSslKey(params.getSslKey());
        upObj.setSslType(Integer.valueOf(0));
        final StrFile strFile = new StrFile();
        strFile.setContent(nginxConfig);
        strFile.setFileName(domain + ".conf");
        strFile.setContentType("text/plain");
        final R<SysFile> r1 = (R<SysFile>)this.remoteFileService.uploadStrToMinio(strFile);
        if (r1.getCode() != Constants.SUCCESS) {
            return AjaxResult.error(r1.getMsg());
        }
        final String nginxUrl = ((SysFile)r1.getData()).getUrl();
        upObj.setNginxCnf(nginxUrl);
        upObj.setSslType(params.getType());
        this.updateSnServerTemplate(upObj);
        final SnServerTask task = this.createShellTaskKernel.deploySSL(this.snServerTemplateMapper.selectSnServerTemplateById(template.getId()), params);
        if (task != null) {
            this.serverTaskSender.sendOrderMessage(task.getTaskId());
            if (task.getProcess() != null) {
                final SnServer upServer = new SnServer();
                upServer.setServerId(server.getServerId());
                upServer.setTaskId(task.getTaskId());
                this.snServerMapper.updateSnServer(upServer);
            }
        }
        return AjaxResult.success("部署中，请稍后查看服务器任务状态");
    }
    
    public AjaxResult updateUI(final UpdateBaseParams params) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        final SnServerTemplate template = this.selectSnServerTemplateById(params.getId());
        if (template == null) {
            return AjaxResult.error("未查询到服务器信息");
        }
        if (!Objects.equals(template.getStatus(), 2)) {
            return AjaxResult.error("此客户端处于【" + this.dictDataService.selectDictLabel("server_templ_status", template.getStatus().toString()) + "】状态，不能更新UI");
        }
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !Objects.equals(template.getCreateId(), loginUser.getUserid()) && !Objects.equals(template.getAgentId(), loginUser.getUserid())) {
            return AjaxResult.error("您无权操作此服务器客户端");
        }
        final SnTemplate font = this.snTemplateMapper.selectSnTemplateByTemplateId(template.getTemplateId());
        if (font == null) {
            return AjaxResult.error("未获取到模板，请联系管理员");
        }
        if (!Objects.equals(font.getStatus(), 1)) {
            return AjaxResult.error("当前模板已下架");
        }
        if (Objects.equals(template.getVersion(), font.getVersion())) {
            return AjaxResult.error("当前已是最新版本");
        }
        params.setVersion(font.getVersion());
        params.setPackUrl(font.getPackUrl());
        final SnServerTemplate upObj = new SnServerTemplate();
        upObj.setId(template.getId());
        upObj.setVersion(font.getVersion());
        Label_0436: {
            if (Objects.equals(font.getCategory(), 6)) {
                try {
                    final SnServer server = this.snServerMapper.selectSnServerByServerId(template.getServerId());
                    final Path newZipPath = ZipTool.generateWpPlugin(font.getPackUrl(), template.getDomain(), server.getDomain(), this.wpPluginName);
                    final MultipartFile file = FileConversionUtil.pathToMultipartFile(newZipPath);
                    final R<SysFile> fileResult = (R<SysFile>)this.remoteFileService.upload(file);
                    ZipTool.deleteDirectory(newZipPath);
                    if (StringUtils.isNull((Object)fileResult) || StringUtils.isNull(fileResult.getData())) {
                        return AjaxResult.error("生成插件异常，请稍后再试");
                    }
                    final String url = ((SysFile)fileResult.getData()).getUrl();
                    upObj.setNginxCnf(url);
                    break Label_0436;
                }
                catch (final Exception ignore) {
                    return AjaxResult.error("生成插件异常，请稍后再试");
                }
            }
            final SnServerTask task = this.createShellTaskKernel.updateUI(template, params);
            if (task != null) {
                this.serverTaskSender.sendOrderMessage(task.getTaskId());
            }
        }
        this.updateSnServerTemplate(upObj);
        return AjaxResult.success("部署中，请稍后查看服务器任务状态");
    }
    
    public AjaxResult haveUpdate(final UpdateBaseParams params) {
        final SnServerTemplate obj = new SnServerTemplate();
        obj.setServerId(params.getId());
        obj.setStatus(Integer.valueOf(2));
        final List<SnServerTemplate> templates = this.selectSnServerTemplateList(obj);
        if (templates.isEmpty()) {
            return AjaxResult.success("操作成功", (Object)false);
        }
        final Long[] templateIds = templates.stream().map((Function<? super Object, ?>)SnServerTemplate::getTemplateId).distinct().toArray(Long[]::new);
        final SnTemplate snTemplate = new SnTemplate();
        snTemplate.getParams().put("excludeBack", 1);
        snTemplate.getParams().put("templateIds", templateIds);
        final List<SnTemplate> tempList = this.snTemplateMapper.selectSnTemplateList(snTemplate);
        final Map<Long, SnTemplate> tempMap = tempList.stream().collect(Collectors.toMap((Function<? super Object, ? extends Long>)SnTemplate::getTemplateId, (Function<? super Object, ? extends SnTemplate>)Function.identity()));
        boolean haveUpdate = Boolean.FALSE;
        for (final SnServerTemplate template : templates) {
            final SnTemplate font = tempMap.get(template.getTemplateId());
            if (font == null) {
                continue;
            }
            if (!params.getTypes().contains(font.getCategory())) {
                continue;
            }
            if (Objects.equals(font.getStatus(), 1) && !Objects.equals(template.getVersion(), font.getVersion())) {
                haveUpdate = Boolean.TRUE;
                break;
            }
        }
        return AjaxResult.success("操作成功", (Object)haveUpdate);
    }
    
    public List<JSONObject> haveUpdateDetail(final Long serverId) {
        final SnServerTemplate obj = new SnServerTemplate();
        obj.setServerId(serverId);
        obj.setStatus(Integer.valueOf(2));
        final List<SnServerTemplate> templates = this.snServerTemplateMapper.selectSnServerTemplateList(obj);
        if (templates.isEmpty()) {
            return new ArrayList<JSONObject>();
        }
        final Long[] templateIds = templates.stream().map((Function<? super Object, ?>)SnServerTemplate::getTemplateId).distinct().toArray(Long[]::new);
        final SnTemplate snTemplate = new SnTemplate();
        snTemplate.getParams().put("excludeBack", 1);
        snTemplate.getParams().put("templateIds", templateIds);
        final List<SnTemplate> tempList = this.snTemplateMapper.selectSnTemplateList(snTemplate);
        final Map<Long, SnTemplate> tempMap = tempList.stream().collect(Collectors.toMap((Function<? super Object, ? extends Long>)SnTemplate::getTemplateId, (Function<? super Object, ? extends SnTemplate>)Function.identity()));
        final List<JSONObject> list = new ArrayList<JSONObject>();
        for (final SnServerTemplate template : templates) {
            final JSONObject json = new JSONObject();
            json.put((Object)"version", (Object)template.getVersion());
            json.put((Object)"domain", (Object)template.getDomain());
            final SnTemplate font = tempMap.get(template.getTemplateId());
            if (font != null) {
                json.put((Object)"category", (Object)font.getCategory());
                json.put((Object)"templateName", (Object)font.getName());
                json.put((Object)"country", (Object)font.getCountry());
                json.put((Object)"language", (Object)font.getLanguage());
                if (Objects.equals(font.getStatus(), 1)) {
                    json.put((Object)"versionNew", (Object)font.getVersion());
                }
            }
            list.add(json);
        }
        return list;
    }
    
    public AjaxResult updateAllUI(final UpdateBaseParams params) {
        final SnServerTemplate obj = new SnServerTemplate();
        obj.setServerId(params.getId());
        obj.setStatus(Integer.valueOf(2));
        final List<SnServerTemplate> templates = this.selectSnServerTemplateList(obj);
        if (templates.isEmpty()) {
            return AjaxResult.error("未查询到服务器信息");
        }
        final Long[] templateIds = templates.stream().map((Function<? super Object, ?>)SnServerTemplate::getTemplateId).distinct().toArray(Long[]::new);
        final SnTemplate snTemplate = new SnTemplate();
        snTemplate.getParams().put("excludeBack", 1);
        snTemplate.getParams().put("templateIds", templateIds);
        final List<SnTemplate> tempList = this.snTemplateMapper.selectSnTemplateList(snTemplate);
        final Map<Long, SnTemplate> tempMap = tempList.stream().collect(Collectors.toMap((Function<? super Object, ? extends Long>)SnTemplate::getTemplateId, (Function<? super Object, ? extends SnTemplate>)Function.identity()));
        final SnServer server = this.snServerMapper.selectSnServerByServerId(templates.get(0).getServerId());
        final List<JSONObject> updates = new ArrayList<JSONObject>();
        for (final SnServerTemplate template : templates) {
            final JSONObject json = new JSONObject();
            json.put((Object)"templateId", (Object)template.getId());
            json.put((Object)"templateName", (Object)template.getTemplateName());
            json.put((Object)"domain", (Object)template.getDomain());
            final SnTemplate font = tempMap.get(template.getTemplateId());
            if (font == null) {
                json.put((Object)"result", (Object)"未获取到模板");
                updates.add(json);
            }
            else {
                if (!params.getTypes().contains(font.getCategory())) {
                    continue;
                }
                if (!Objects.equals(font.getStatus(), 1)) {
                    json.put((Object)"result", (Object)"当前模板已下架");
                    updates.add(json);
                }
                else if (Objects.equals(template.getVersion(), font.getVersion())) {
                    json.put((Object)"result", (Object)"已是最新版本");
                    updates.add(json);
                }
                else {
                    params.setVersion(font.getVersion());
                    params.setPackUrl(font.getPackUrl());
                    final SnServerTemplate upObj = new SnServerTemplate();
                    upObj.setId(template.getId());
                    upObj.setVersion(font.getVersion());
                    Label_0650: {
                        if (Objects.equals(font.getCategory(), 6)) {
                            try {
                                final Path newZipPath = ZipTool.generateWpPlugin(font.getPackUrl(), template.getDomain(), server.getDomain(), this.wpPluginName);
                                final MultipartFile file = FileConversionUtil.pathToMultipartFile(newZipPath);
                                final R<SysFile> fileResult = (R<SysFile>)this.remoteFileService.upload(file);
                                ZipTool.deleteDirectory(newZipPath);
                                if (StringUtils.isNull((Object)fileResult) || StringUtils.isNull(fileResult.getData())) {
                                    return AjaxResult.error("生成插件异常，请稍后再试");
                                }
                                final String url = ((SysFile)fileResult.getData()).getUrl();
                                upObj.setNginxCnf(url);
                                json.put((Object)"result", (Object)"部署中");
                                break Label_0650;
                            }
                            catch (final Exception ignore) {
                                return AjaxResult.error("生成插件异常，请稍后再试");
                            }
                        }
                        final SnServerTask task = this.createShellTaskKernel.updateUI(template, params);
                        if (task != null) {
                            this.serverTaskSender.sendOrderMessage(task.getTaskId());
                        }
                        json.put((Object)"result", (Object)"部署中");
                    }
                    this.updateSnServerTemplate(upObj);
                    updates.add(json);
                }
            }
        }
        return AjaxResult.success("操作成功", (Object)updates);
    }
    
    public AjaxResult updateClientConfig(final SnServerTemplate template, final String domain, final Integer category) {
        final SnServer server = this.snServerMapper.selectSnServerByServerId(template.getServerId());
        final SysUser common = this.sysUserService.selectUserById(server.getCreateId());
        final String url = ((server.getSslType() == null || server.getSslType() == 0) ? "http://" : "https://") + server.getDomain() + "/api/user/config/updateDomain";
        final JSONObject params = new JSONObject().fluentPut("license", (Object)common.getLicense()).fluentPut("serverTemplateId", (Object)template.getId()).fluentPut("domain", (Object)domain).fluentPut("category", (Object)category);
        final String res = new RequestUtil().doPostJson(url, params.toJSONString(new JSONWriter.Feature[0]));
        System.out.println("更新客户端域名结果：" + res);
        try {
            final JSONObject json = JSONObject.parseObject(res);
            if (!Objects.equals(json.getInteger("code"), 200)) {
                return AjaxResult.error("更新客户端域名失败，请稍后再试");
            }
            return AjaxResult.success();
        }
        catch (final Exception ignore) {
            return AjaxResult.error("更新客户端域名失败，请稍后再试");
        }
    }
}
